@@ -212,9 +212,9 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
-minvGauss(2, 3, 4) 
+minvGauss(2, 3, 4)
 levinvGauss(10, 3, 4)
-mgfinvGauss(1,3,2)
+mgfinvGauss(0.2, 3, 4)
 
 
 
